How I found/navigated through these datasets (copied from my personal dynalist on 2025-01-05):

[1] PDS Geosciences Node (homepage) — https://pds-geosciences.wustl.edu/default.htm
[2] Gravity Models (overview) — https://pds-geosciences.wustl.edu/dataserv/gravity_models.htm
    - Found in [1] by clicking "Gravity Models" in sidebar
[3] Gravity Model Description — https://pds-geosciences.wustl.edu/dataserv/gravity_model_desc.htm
    - Found in [2] in the description paragraph (beneath main title)
[4] DOWNLOADS HERE (pds-geosciences.wustl.edu - /mro/mro-m-rss-5-sdp-v1/mrors_1xxx/data/rsdmap/) — https://pds-geosciences.wustl.edu/mro/mro-m-rss-5-sdp-v1/mrors_1xxx/data/rsdmap/
    - Found in [2] in the table, as the first (i.e. most recent) link under "Mars"

(SEE ASSOCIATED `.lbl` FOR MORE INFO ABOUT DATASET)
